@@ -88,8 +88,10 @@ bool loadSymbol(void* pLib, const std::string& name, void** ppSymbol, std::strin
 #endif
   if (*ppSymbol == NULL)
   {
-    lastDLErrorMessage(pError);
-    *pError = name + " - " + *pError;
+    if (pError != NULL) {
+      lastDLErrorMessage(pError);
+      *pError = name + " - " + *pError;
+    }
     return false;
   }
   else
@@ -170,6 +172,11 @@ bool SharedLibrary::load(const std::string& libPath, bool python3, std::string*
   return loadSymbols(python3, pError);
 }
 
+// Define "slow" fallback implementation for Py version <= 3.9
+int _PyIter_Check(PyObject* o) {
+  return PyObject_HasAttrString(o, "__next__");
+}
+
 
 bool LibPython::loadSymbols(bool python3, std::string* pError)
 {
@@ -283,6 +290,7 @@ bool LibPython::loadSymbols(bool python3, std::string* pError)
   // PyUnicode_AsEncodedString may have several different names depending on the Python
   // version and the UCS build type
   std::vector<std::string> names;
+  names.reserve(3);
   names.push_back("PyUnicode_AsEncodedString");
   names.push_back("PyUnicodeUCS2_AsEncodedString");
   names.push_back("PyUnicodeUCS4_AsEncodedString");
@@ -339,6 +347,12 @@ bool LibPython::loadSymbols(bool python3, std::string* pError)
   LOAD_PYTHON_SYMBOL(PyCapsule_GetContext)
   LOAD_PYTHON_SYMBOL(Py_BuildValue)
 
+  // LOAD_PYTHON_SYMBOL(PyIter_Check) // only available beginning in 3.10
+  // Try to load the symbol, and if it fails, set it to the internal function
+  if (!loadSymbol(pLib_, "PyIter_Check", (void**)&PyIter_Check, NULL)) {
+    PyIter_Check = &_PyIter_Check;
+  }
+
   return true;
 }
 
